==> pointpos_api-0.0.16.tar.gz: doc/PromoApi.md <==
# pointpos_api.api.PromoApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createPromo**](PromoApi.md#createPromo) | **Post** /promo | Create Promo
[**deletePromoByID**](PromoApi.md#deletePromoByID) | **Delete** /promo/:id | Delete Promo By ID
[**findPromo**](PromoApi.md#findPromo) | **Get** /promo | Get Promo List
[**getPromoByID**](PromoApi.md#getPromoByID) | **Get** /promo/:id | Get Promo By ID
[**updatePromoByID**](PromoApi.md#updatePromoByID) | **Put** /promo/:id | Update Promo By ID


# **createPromo**
> Promo createPromo(authorization, xAPIKey, body, xPin)

Create Promo

Create Promo

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new Promo(); // Promo | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createPromo(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->createPromo: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**Promo**](Promo.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Promo**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deletePromoByID**
> deletePromoByID(authorization, xAPIKey, id, xPin)

Delete Promo By ID

Delete Promo By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deletePromoByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling PromoApi->deletePromoByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findPromo**
> List<Promo> findPromo(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter)

Get Promo List

Get Promo  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"promoType\"   - \"assignedOutlets\"   - \"requirement\"   - \"reward\"   - \"allowMultiple\"   - \"promoPeriod\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findPromo(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->findPromo: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;promoType\&quot;   - \&quot;assignedOutlets\&quot;   - \&quot;requirement\&quot;   - \&quot;reward\&quot;   - \&quot;allowMultiple\&quot;   - \&quot;promoPeriod\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]

### Return type

[**List<Promo>**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPromoByID**
> Promo getPromoByID(authorization, xAPIKey, id, xPin)

Get Promo By ID

Get Promo By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getPromoByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->getPromoByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Promo**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePromoByID**
> Promo updatePromoByID(authorization, xAPIKey, id, body, xPin)

Update Promo By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new Promo(); // Promo | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updatePromoByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->updatePromoByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**Promo**](Promo.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Promo**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.2.1.tar.gz: doc/PromoApi.md <==
# pointpos_api.api.PromoApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createPromo**](PromoApi.md#createPromo) | **Post** /promo | Create Promo
[**deletePromoByID**](PromoApi.md#deletePromoByID) | **Delete** /promo/:id | Delete Promo By ID
[**findPromo**](PromoApi.md#findPromo) | **Get** /promo | Get Promo List
[**getPromoByID**](PromoApi.md#getPromoByID) | **Get** /promo/:id | Get Promo By ID
[**updatePromoByID**](PromoApi.md#updatePromoByID) | **Put** /promo/:id | Update Promo By ID


# **createPromo**
> Promo createPromo(authorization, xAPIKey, body, xPin)

Create Promo

Create Promo

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new Promo(); // Promo | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createPromo(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->createPromo: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**Promo**](Promo.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Promo**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deletePromoByID**
> deletePromoByID(authorization, xAPIKey, id, xPin)

Delete Promo By ID

Delete Promo By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deletePromoByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling PromoApi->deletePromoByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findPromo**
> List<Promo> findPromo(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted)

Get Promo List

Get Promo  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'createdAt|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"promoType\"   - \"assignedOutlets\"   - \"requirement\"   - \"reward\"   - \"allowMultiple\"   - \"promoPeriod\"   - \"createdAt\"   - \"createdBy\"   - \"updatedAt\"   - \"updatedBy\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 
var withDeleted = true; // bool | Return with deleted resource

try { 
    var result = api_instance.findPromo(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->findPromo: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;createdAt|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;promoType\&quot;   - \&quot;assignedOutlets\&quot;   - \&quot;requirement\&quot;   - \&quot;reward\&quot;   - \&quot;allowMultiple\&quot;   - \&quot;promoPeriod\&quot;   - \&quot;createdAt\&quot;   - \&quot;createdBy\&quot;   - \&quot;updatedAt\&quot;   - \&quot;updatedBy\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]
 **withDeleted** | **bool**| Return with deleted resource | [optional] [default to false]

### Return type

[**List<Promo>**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPromoByID**
> Promo getPromoByID(authorization, xAPIKey, id, xPin)

Get Promo By ID

Get Promo By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getPromoByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->getPromoByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Promo**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePromoByID**
> Promo updatePromoByID(authorization, xAPIKey, id, body, xPin)

Update Promo By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PromoApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new Promo(); // Promo | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updatePromoByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PromoApi->updatePromoByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**Promo**](Promo.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**Promo**](Promo.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
